
/**
 * Generic styles
 */

BODY {
	margin: 0px;
	padding: 0px;
	color: #666;
	background-color: #444;
}

BODY,
INPUT,
SELECT {
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
	font-size: 12px;
}

TEXTAREA {
	font-size: 90%;
}

DIV.centered {
	text-align: center;
}

DIV.row DIV.label {
	color: #999;
	font-weight: bold;
	padding-left: 3px;
	border-bottom: 1px solid #cdcdcd;
}

DIV.row LABEL SPAN:last-child {
	margin-right: 6px;
}

DIV.row DIV.widget {
	margin: 2px 0px 8px;
	padding-left: 3px;
	position: relative;
}

DIV.input LABEL SPAN.required {
	font-weight: bold;
	color: red;
}

A {
	text-decoration: none;
	outline: 0;
	color: #333;
}
A:active {
	text-decoration: underline;
}

A:visited {
	text-decoration: none;
	color: #333;
}

A.hint {
	position: relative;
	bottom: 2px;
	color: #666;
	font-size: 90%;
	font-weight: bold;
	padding: 0px 2px;
	text-decoration: none;
	opacity: 0.7;
	filter: alpha(opacity = 70);
}

A.hint:hover {
	opacity: 1.0;
	filter: alpha(opacity = 100);
}

.download-link {
	display: inline-block;
	margin-left: 5px;
	padding: 1px 6px;
	background-color: #ccc;
	border: 1px solid rgba(126,141,173,1);
	border-radius: 3px;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
	color: rgb(126,141,173);
	text-shadow: none;
}

LEGEND A.hint {
	bottom: 0px;
	margin-left: 5px;
}

.hidden {
	display: none;
}

.toleft {
	float: left;
}

.toright {
	float: right;
}

.nofloat {
	float: none !important;
}

DIV.clearer {
	clear: both;
	height: 0px !important;
	font-size: 0px;
}

DIV.cthumb {
	position: absolute;
	top: -1px;
	left: -1px;
	width: 30px;
	height: 30px;
	border: 1px solid red;
	z-index: 2;
}

DIV.current-value {
	padding: 0px 4px;
}

DIV.download-link {
	position: relative;
}

DIV.download-link IMG {
	vertical-align: top;
	border: 0px;
	margin: 2px;
}

DIV.tipsy-inner {
	max-width: 300px;
}

SPAN.light {
	font-weight: lighter;
	font-size: 80%;
}

.btn-small {
	padding: 0px 4px 2px !important;
	border: 1px solid #ccc;
	margin-top: 3px;
	border-radius: 3px;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

/**
 * Page styles
 */

BODY.ztfy #banner {
	position: absolute;
	left: 0;
	top: 0;
	z-index: -1;
	width: 100%;
	height: 80px;
	box-shadow: 0 1px 0 #333333;
	background-color: #333333;
	background-image: -webkit-gradient(linear, 0 0%, 0 100%, from(#3F3F3F), to(#222222));
	background-image: -webkit-linear-gradient(top, #3F3F3F 0%, #222222 100%);
	background-image: -moz-linear-gradient(top, #3F3F3F 0%, #222222 100%);
	background-image: -ms-linear-gradient(top, #3F3F3F 0%, #222222 100%);
	background-image: -o-linear-gradient(top, #3F3F3F 0%, #222222 100%);
	background-image: linear-gradient(top, #3F3F3F 0%, #222222 100%);
	border-bottom: 1px solid #555555;
}

BODY.ztfy #banner IMG.banner {
	margin-left: 220px;
}

BODY.ztfy #banner IMG.logo {
	position: absolute;
	bottom: 10px;
	left: 10px;
	max-width: 200px;
}

#header {
	margin-top: 20px;
	margin-left: 220px;
	padding: 20px 0px 10px;
	background-color: #eee;
	border-top-left-radius: 8px;
}

BODY.login #header {
	width: 700px;
	margin: 20px auto 0px;
	border-top-right-radius: 8px;
}

#header H1,
DIV.dialog H1 {
	padding-left: 20px;
	font-size: 28px;
	font-weight: normal;
	font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;
}

DIV.dialog H1 {
	margin-right: 35px;
	font-size: 22px;
}

#header DIV.crumbs {
	padding: 8px 20px;
	background-color: #e5e5e5;
	border-top: 1px solid #d6d6d6;
	border-bottom: 1px solid #d6d6d6;
	box-shadow: 0 0 1px white;
	color: 
}

#header DIV.crumbs A {
	color: #666;
	padding: 0px 5px;
}

#header DIV.crumbs A.current {
	font-weight: bold;
}

#left_column {
	position: absolute;
	top: 100px;
	width: 220px;
	padding-top: 0px;
}

#right_column {
	float: right;
	width: 15%;
	margin-top: 35px;
	margin-right: 10px;
}

DIV.border-column DIV.actions,
DIV.border-column DIV.workflow,
DIV.border-column DIV.properties,
DIV.border-column DIV.login {
	margin-bottom: 15px;
	border-top: 1px solid #393939;
	border-bottom: 1px solid #4e4e4e;
}

DIV.border-column DIV.actions.zmi_access,
DIV.border-column DIV.actions.zmi_views {
	margin-top: 30px;
}

DIV.border-column DIV.actions H2,
DIV.border-column DIV.workflow H2,
DIV.border-column DIV.properties H2,
DIV.border-column DIV.login H2 {
	margin: 0px 0px 3px;
	padding: 5px 10px;
}

DIV.border-column DIV.actions H2 {
	color: #ccc;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
	background: rgb(79,96,135); /* Old browsers */
	background: -moz-linear-gradient(top,  rgba(79,96,135,1) 0%, rgba(63,76,107,1) 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(79,96,135,1)), color-stop(100%,rgba(63,76,107,1))); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* IE10+ */
	background: linear-gradient(to bottom,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4f6087', endColorstr='#3f4c6b',GradientType=0 ); /* IE6-9 */
}

DIV.border-column A {
	color: #aaa;
	padding: 6px 0px 6px 10px;
	line-height: 20px;
	border-top: 1px solid #4e4e4e;
	border-bottom: 1px solid #393939;
}

DIV.border-column A:hover {
	background-color: #4A4A4A;
}

DIV.border-column A.active-menu-item {
	background: #3a3a3a url(/--static--/ztfy.skin/img/menu-active.png) scroll no-repeat right 50%;
}

DIV.border-column A.submenu {
	background-color: #3a3a3a;
	padding: 3px 0px 3px 12px;
	font-size: 90%;
}

DIV.border-column DIV.workflow H2 {
	color: #ffffff;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
	background-color: #5bb75b;
	background-image: -moz-linear-gradient(top, #62c462, #51a351);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#62c462), to(#51a351));
	background-image: -webkit-linear-gradient(top, #62c462, #51a351);
	background-image: -o-linear-gradient(top, #62c462, #51a351);
	background-image: linear-gradient(to bottom, #62c462, #51a351);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff62c462', endColorstr='#ff51a351', GradientType=0);
	border-color: #51a351 #51a351 #387038;
	border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
	*background-color: #51a351;
	filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}

DIV.border-column DIV.zmi_access H2,
DIV.border-column DIV.zmi_views H2,
DIV.border-column DIV.zmi_actions H2 {
	color: #ffffff;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
	background-color: #faa732;
	background-image: -moz-linear-gradient(top, #fbb450, #f89406);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#fbb450), to(#f89406));
	background-image: -webkit-linear-gradient(top, #fbb450, #f89406);
	background-image: -o-linear-gradient(top, #fbb450, #f89406);
	background-image: linear-gradient(to bottom, #fbb450, #f89406);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fffbb450', endColorstr='#fff89406', GradientType=0);
	border-color: #f89406 #f89406 #ad6704;
	border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
	*background-color: #f89406;
	filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}

DIV.border-column DIV.properties H2.inner {
	margin-top: 5px;
}

DIV.border-column DIV.actions A,
DIV.border-column DIV.workflow A {
	display: block;
	border-radius: 2px;
	-moz-border-radius: 2px;
	-webkit-border-radius: 2px;
}

DIV.border-column A.active-menu-item {
	font-weight: bold;
}

DIV.border-column DIV.actions A.last {
	border-bottom-width: 0;
}

DIV.border-column DIV.actions A.front {
	padding-left: 10px;
}

DIV.border-column DIV.properties DIV,
DIV.border-column DIV.login DIV {
	padding: 2px;
	font-size: 80%;
}

DIV.border-column DIV.properties DIV.history DIV {
	padding: 0px 2px;
}

DIV.border-column DIV.properties SPAN.label,
DIV.border-column DIV.login SPAN.label {
	font-weight: bold;
}

DIV.border-column DIV.properties DIV.switcher {
	cursor: pointer;
}

DIV.border-column DIV.properties DIV.switch {
	display: none;
}

DIV.border-column DIV.properties HR {
	margin: 2px auto;
	border: 1px solid #aaa;
	border-bottom-width: 0px;
}

#container {
	margin-left: 220px;
	background-color: #eee;
}

BODY.login #container {
	margin: 0px auto;
	width: 700px;
}

#content {
	margin-right: 15%;
	padding: 5px 20px 20px;
}

BODY.login #content {
	margin-right: 0px;
}

H1 {
	margin: 0.25em 0 0.5em 0;
	font-size: 150%;
}

H2 {
	margin: 0.15em 0 0.25em 0;
	font-size: 130%;
}

H3 {
	margin: 0.1em 0 0.15em 0;
	font-size: 110%;
}


/**
 * Forms styles
 */

FORM IMG.search {
	width: 16px;
	height: 16px;
	vertical-align: middle;
}

FORM INPUT.search {
	width: 93% !important;
}

DIV.loader {
	text-align: center;
}

DIV.viewspace {
	padding: 5px;
	background-color: #f1f1f1;
	border-radius: 3px;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

DIV.viewspace DIV.scrollmarker {
	position: absolute;
	height: 20px;
	width: 100%;
	margin: 0px -4px;
}

DIV.viewspace DIV.scrollmarker.top {
	background: -moz-linear-gradient(top,  rgba(64,150,238,1) 0%, rgba(153,200,247,0.83) 17%, rgba(255,255,255,0) 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(64,150,238,1)), color-stop(17%,rgba(153,200,247,0.83)), color-stop(100%,rgba(255,255,255,0))); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  rgba(64,150,238,1) 0%,rgba(153,200,247,0.83) 17%,rgba(255,255,255,0) 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  rgba(64,150,238,1) 0%,rgba(153,200,247,0.83) 17%,rgba(255,255,255,0) 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  rgba(64,150,238,1) 0%,rgba(153,200,247,0.83) 17%,rgba(255,255,255,0) 100%); /* IE10+ */
	background: linear-gradient(to bottom,  rgba(64,150,238,1) 0%,rgba(153,200,247,0.83) 17%,rgba(255,255,255,0) 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#4096ee', endColorstr='#00ffffff',GradientType=0 ); /* IE6-9 */
}

DIV.viewspace DIV.scrollmarker.bottom {
	background: -moz-linear-gradient(top,  rgba(255,255,255,0) 0%, rgba(153,200,247,0.83) 83%, rgba(64,150,238,1) 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(255,255,255,0)), color-stop(83%,rgba(153,200,247,0.83)), color-stop(100%,rgba(64,150,238,1))); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  rgba(255,255,255,0) 0%,rgba(153,200,247,0.83) 83%,rgba(64,150,238,1) 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  rgba(255,255,255,0) 0%,rgba(153,200,247,0.83) 83%,rgba(64,150,238,1) 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  rgba(255,255,255,0) 0%,rgba(153,200,247,0.83) 83%,rgba(64,150,238,1) 100%); /* IE10+ */
	background: linear-gradient(to bottom,  rgba(255,255,255,0) 0%,rgba(153,200,247,0.83) 83%,rgba(64,150,238,1) 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#00ffffff', endColorstr='#4096ee',GradientType=0 ); /* IE6-9 */
}

DIV.form H1,
DIV.display-form H1 {
	margin-bottom: 15px;
	padding: 3px 6px;
	border-top: 4px solid #b1b7c1;
	border-bottom: 4px solid #b1b7c1;
}

DIV.dialog {
	background-color: #eee;
	border-radius: 5px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
}

DIV.dialog TABLE {
	width: 100%;
}

DIV.form FIELDSET,
DIV.display-form FIELDSET {
	position: relative;
	background-color: #f9f9f9;
	margin: 5px 0px 0px;
	padding: 13px;
	border: 1px solid #cdcdcd;;
	border-radius: 3px;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

DIV.form FIELDSET.switched,
DIV.display-form FIELDSET.switched {
	margin-left: 7px;
	margin-right: 7px;
	padding: 0px 6px !important;
	border-color: transparent;
	background-color: transparent;
}

DIV.dialog DIV.form,
DIV.dialog DIV.display-form {
	padding: 0px 5px 5px;
}

DIV.form LEGEND,
DIV.display-form LEGEND {
	padding: 5px 10px;
	color: #666;
	background-color: #EFEFEF;
	background-image: -webkit-gradient(linear, 0 0%, 0 100%, from(#FDFDFD), to(#EAEAEA));
	background-image: -webkit-linear-gradient(top, #FDFDFD 0%, #EAEAEA 100%);
	background-image: -moz-linear-gradient(top, #FDFDFD 0%, #EAEAEA 100%);
	background-image: -ms-linear-gradient(top, #FDFDFD 0%, #EAEAEA 100%);
	background-image: -o-linear-gradient(top, #FDFDFD 0%, #EAEAEA 100%);
	background-image: -linear-gradient(top, #FDFDFD 0%, #EAEAEA 100%);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fdfdfd', endColorstr='#eaeaea',GradientType=0 );
	border: 1px solid #cdcdcd;
	font-size: 115%;
	font-weight: bold;
	border-radius: 2px;
	-moz-border-radius: 2px;
	-webkit-border-radius: 2px;
}

DIV.form LEGEND IMG,
DIV.display-form LEGEND IMG {
	position: relative;
	top: 2px;
}

DIV.workflow-form LEGEND {
	color: #fbffee;
	background-color: #adbd78;
	border: 1px solid #adbd78;
}

DIV.form FIELDSET FIELDSET,
DIV.display-form FIELDSET FIELDSET {
	border-color: #dcdcdc;
}

DIV.form FIELDSET FIELDSET LEGEND,
DIV.display-form FIELDSET FIELDSET LEGEND {
	font-size: 105%;
	background-color: #EFEFEF;
	background-image: -webkit-gradient(linear, 0 0%, 0 100%, from(#fefefe), to(#fafafa));
	background-image: -webkit-linear-gradient(top, #fefefe 0%, #fafafa 100%);
	background-image: -moz-linear-gradient(top, #fefefe 0%, #fafafa 100%);
	background-image: -ms-linear-gradient(top, #fefefe 0%, #fafafa 100%);
	background-image: -o-linear-gradient(top, #fefefe 0%, #fafafa 100%);
	background-image: -linear-gradient(top, #fefefe 0%, #fafafa 100%);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fefefe', endColorstr='#fafafa',GradientType=0 );
	border: 1px solid #dcdcdc;
	padding: 3px 8px;
}

DIV.form FIELDSET FIELDSET FIELDSET LEGEND,
DIV.display-form FIELDSET FIELDSET FIELDSET LEGEND {
	padding: 3px 5px;
	background: white;
	font-size: 100%;
}

DIV.form FIELDSET FIELDSET.inner LEGEND,
DIV.display-form FIELDSET FIELDSET.inner LEGEND {
	background-color: #edf0f6;
	color: #b1b7c1;
	border-color: #c1c7c1;
}

DIV.form FIELDSET INPUT[type=text],
DIV.form FIELDSET TEXTAREA {
	width: 96%;
	margin-top: 0px;
}

DIV.form DIV.subforms FIELDSET.inner,
DIV.display-form DIV.subforms FIELDSET.inner {
	margin: 0px 0px 10px;
	padding-bottom: 0px;
	border: 1px solid #dedede;
}

DIV.required-info {
	position: absolute;
	right: 0px;
	top: 0px;
	padding: 2px 5px;
	color: #b1b7c1;
	margin-bottom: 5px;
	font-style: italic;
	font-size: 90%;
}

FIELDSET > LEGEND + DIV.required-info {
	top: 15px;
}

DIV.required-info SPAN.required {
	color: red;
}

DIV.help {
	padding: 4px 10px;
	margin-bottom: 10px;
	color: #ac8542;
	background-color: #f5f0e7;
	border: 1px solid #e7dac0;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
	font-size: 90%;
}

DIV.status {
	margin: 0px 0px 5px;
	padding: 4px 10px;
	color: #3a87ad;
	background-color: #d9edf7;
	border: 1px solid #bce8f1;
	font-size: 11px;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
}

DIV.status.success {
	color: #468847;
	background-color: #dff0d8;
	border-color: #d6e9c6;
}

DIV.status.warning {
	color: #ff9500;
	background-color: #fff0db;
	border-color: #fbeed5;
}

DIV.status.error {
	color: #b94a48;
	background-color: #f2dede;
	border-color: #eed3d7;
}

DIV.status DIV.summary {
	font-weight: bold;
}

DIV.status UL {
	margin: 0.3em 0px;
}

DIV.status UL.errors LI {
	list-style-position: inside;
}

UL.errors DIV.error {
	display: inline;
}

DIV.row DIV.error DIV.error {
	border: none;
	float: right;
	padding-right: 2px;
	color: #B94A48;
	font-size: 90%;
}

SELECT,
TEXTAREA,
INPUT[type="text"],
INPUT[type="password"] {
	margin-left: 3px;
	border: 1px solid #dcdcdc;
	padding: 3px;
	color: #666;
	background-color: white;
	border-radius: 3px;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

INPUT[type="file"] {
	width: 96%;
	border: 1px solid #dcdcdc;
	background-color: #eee;
	padding: 2px 4px;
}

DIV.row DIV.error DIV.widget TEXTAREA,
DIV.row DIV.error DIV.widget INPUT[type="text"],
DIV.row DIV.error DIV.widget INPUT[type="password"] {
	border-width: 1px;
	border-color: #B94A48;
	padding-left: 4px;
}

SELECT:focus,
TEXTAREA:focus,
INPUT[type="text"]:focus,
INPUT[type="password"]:focus {
	border-color: rgba(82, 168, 236, 0.8);
	outline: 0;
	outline: thin dotted 9;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(82, 168, 236, 0.6);
	-moz-box-shadow: inset 0 1px 1px rgba(0,0,0,0.075),0 0 8px rgba(82,168,236,0.6);
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075),0 0 8px rgba(82, 168, 236, 0.6);
}

TABLE.ordered-selection-field {
	width: auto !important;
}

TABLE.ordered-selection-field SELECT {
	width: 250px;
}

DIV.buttons {
	text-align: right;
	padding: 15px 15% 5px;
}

INPUT.submit-widget,
INPUT.button-widget,
#popup_container INPUT[type=button] {
	border: 2px solid rgba(79,96,135,1);
	color: #ccc;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
	background: rgb(79,96,135); /* Old browsers */
	background: -moz-linear-gradient(top,  rgba(79,96,135,1) 0%, rgba(63,76,107,1) 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(79,96,135,1)), color-stop(100%,rgba(63,76,107,1))); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* IE10+ */
	background: linear-gradient(to bottom,  rgba(79,96,135,1) 0%,rgba(63,76,107,1) 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#4f6087', endColorstr='#3f4c6b',GradientType=0 ); /* IE6-9 */
	padding: 5px 15px;
	font-size: 110%;
	font-weight: bold;
	border-radius: 4px;
	-moz-border-radius: 4px;
	-webkit-border-radius: 4px;
}

INPUT.submit-widget:hover,
INPUT.button-widget:hover,
#popup_container INPUT[type=button]:hover {
	color: #eee;
	background: rgb(126,141,173); /* Old browsers */
	background: -moz-linear-gradient(top,  rgba(126,141,173,1) 0%, rgba(108,121,153,1) 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(126,141,173,1)), color-stop(100%,rgba(108,121,153,1))); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* IE10+ */
	background: linear-gradient(to bottom,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#7e8dad', endColorstr='#6c7999',GradientType=0 ); /* IE6-9 */
}

DIV.row DIV.multi-widget DIV.row {
	clear: both;
}

DIV.row DIV.multi-widget DIV.label {
	display: none;
}

DIV.row DIV.multi-widget DIV.multi-widget-checkbox {
	float: right;
}

DIV.row DIV.multi-widget DIV.buttons INPUT {
	border: 1px solid rgba(126,141,173,1);
	color: #ccc;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
	background: rgb(126,141,173); /* Old browsers */
	background: -moz-linear-gradient(top,  rgba(126,141,173,1) 0%, rgba(108,121,153,1) 100%); /* FF3.6+ */
	background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,rgba(126,141,173,1)), color-stop(100%,rgba(108,121,153,1))); /* Chrome,Safari4+ */
	background: -webkit-linear-gradient(top,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* Chrome10+,Safari5.1+ */
	background: -o-linear-gradient(top,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* Opera 11.10+ */
	background: -ms-linear-gradient(top,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* IE10+ */
	background: linear-gradient(to bottom,  rgba(126,141,173,1) 0%,rgba(108,121,153,1) 100%); /* W3C */
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#7e8dad', endColorstr='#6c7999',GradientType=0 ); /* IE6-9 */
}

DIV.row DIV.multi-widget DIV.buttons INPUT:hover {
	color: #eee;
}

DIV.row.display A.bit-box {
	color: #666;
	padding-right: 5px;
	border-color: #ccc;
	background-color: #eee;
}

DIV.row.display A.bit-box:hover {
	border-color: #bbb;
	background-color: white;
}


/**
 * Tables
 */

TABLE {
	width: 100%;
	border: 1px solid #cdcdcd;
	border-right: none;
	border-bottom: none;
	border-spacing: 0px 0px;
}

TABLE.orderable TR,
TABLE.treeview TR {
	margin: 2px 0px;
}

TABLE TH {
	text-align: left;
	padding-left: 20px;
	font-weight: normal;
	font-size: 90%;
	background-color: #efefef;
	background-image: -webkit-gradient(linear, 0 0%, 0 100%, from(#fdfdfd), to(#eaeaea));
	background-image: -webkit-linear-gradient(top, #fdfdfd 0%, #eaeaea 100%);
	background-image: -moz-linear-gradient(top, #fdfdfd 0%, #eaeaea 100%);
	background-image: -ms-linear-gradient(top, #fdfdfd 0%, #eaeaea 100%);
	background-image: -o-linear-gradient(top, #fdfdfd 0%, #eaeaea 100%);
	background-image: -linear-gradient(top, #fdfdfd 0%, #eaeaea 100%);
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fdfdfd', endColorstr='#eaeaea',GradientType=0 ); /* IE6-9 */
	border-bottom: 1px solid #dcdcdc;
	border-right: 1px solid #dcdcdc;
	height: 25px;
}

TABLE.orderable TH.sorter,
TABLE.orderable TH.hidden,
TABLE.orderable TH.preview,
TABLE.treeview TH.hidden {
	padding-left: 0px;
	border-right: none;
}

TABLE.orderable TH.sorter {
	width: 16px;
	text-align: center;
}

TABLE.orderable TH.preview {
	width: 70px;
}

TABLE.orderable IMG.handler {
	padding-top: 2px;
}

TABLE.orderable TR.sorting-holder {
	height: 20px;
}

TABLE TD {
	padding: 2px 5px;
	background-color: #f9f9f9;
	border-right: 1px solid #dcdcdc;
	border-bottom: 1px solid #d6d6d6;
}

TABLE.orderable TD.sorter {
	border-right: 0px;
}

TABLE TR:hover TD {
	background-color: #e9e9e9;
}

TABLE .ui-icon {
	float: left;
	height: 12px;
}

TABLE.treeview TR.accept TD.title {
	background-color: white;
	padding-bottom: 16px;
}

TABLE.treeview TR.ui-draggable-dragging TD.title {
	width: 250px;
}

TABLE.orderable TD.preview {
	text-align: center;
	padding-right: 6px;
}

TABLE.treeview TD.title IMG {
	vertical-align: middle;
	padding-bottom: 2px;
}

TABLE TR.site TD.title .ui-icon {
	background-position: 0px -115px;
}

TABLE TR.blog TD.title .ui-icon {
	background-position: -192px -115px;
}

TABLE TR.section TD.title .ui-icon {
	background-position: -16px -100px;
}

TABLE TR.topic TD.title .ui-icon {
	background-image: url(/--static--/ztfy.jqueryui/img/ui-icons_cd0a0a_256x240.png) !important;
	background-position: -32px -99px;
}

TABLE.treeview TR.collapsed TD.title .ui-icon {
	background-image: url(/--static--/ztfy.jqueryui/img/ui-icons_888888_256x240.png);
}

TABLE.foldertree TD.title .ui-icon {
	background-position: -16px -100px;
}

TABLE TD.title {
	width: 50%;
}

TABLE TD.centered,
TABLE TD.date {
	text-align: center;
}

TABLE TD.size {
	text-align: right;
	padding-right: 10px;
}

TABLE TD.size,
TABLE TD.date {
	white-space: nowrap;
}

TABLE TD.status {
	color: #2e83ff;
}

TABLE.treeview TD.status .ui-workflow {
	margin-left: 10px;
}

TABLE TD.status .ui-workflow {
	background-image: url(/--static--/ztfy.jqueryui/img/ui-icons_2e83ff_256x240.png) !important;
}

TABLE TD.status .ui-icon-draft {
	background-position: -177px -115px;
}

TABLE TD.status .ui-icon-published {
	background-position: -144px -99px;
}

TABLE TD.status .ui-icon-retired {
	background-position: 0px -130px;
}

TABLE TD.status .ui-icon-archived {
	background-position: -193px -99px;
}

TABLE TD.actions .ui-icon {
	cursor: pointer;
}

TABLE TD.actions .ui-icon-trash {
	background-position: -176px -99px;
}

TABLE TD.actions .ui-icon-squaresmall-plus {
	background-position: -48px -210px;
}

TABLE.history TR.OK TD {
	background-color: lightgreen;
}

TABLE.history TR.Error TD {
	background-color: #ff3333;
}


/**
 * Batch buttons
 */

DIV.batch {
	margin-top: 10px;
	padding: 5px;
	text-align: center;
}

DIV.batchPages {
	display: inline-block;
	margin: 5px 0px;
	overflow: hidden;
	background-color: #efefef;
	background-image: -moz-linear-gradient(#fff, #efefef);
	background-image: -webkit-linear-gradient(#fff, #efefef);
	background-image: linear-gradient(#fff, #efefef);
	background-repeat: repeat-x;
	border: 1px solid #eaeaea;
	border-bottom-color: #cacaca;
	border-bottom: none;
	border-radius: 3px;
}

DIV.batchPages A {
	float: left;
	padding: 5px 6px 4px;
	margin: 0;
	color: #777;
	text-decoration: none;
	text-shadow: 0 1px 0 white;
	border-top: 1px solid transparent;
	border-right: 1px solid rgba(0,0,0,0.04);
	border-left: 1px solid rgba(255,255,255,0.7);
	border-bottom: 1px solid #dadada;
}

DIV.batchPages A[href]:hover {
	background-color: #efefef;
	background-image: -moz-linear-gradient(#efefef, #fff);
	background-image: -webkit-linear-gradient(#efefef, #fff);
	background-image: linear-gradient(#efefef, #fff);
	border-left: 1px solid rgba(0,0,0,0.04);
	border-right: 1px solid rgba(255,255,255,0.7);
	border-top: 1px solid #dadada;
	border-bottom: 1px solid transparent;
}

DIV.batchPages A:first-child {
	border-left-color: transparent;
	border-bottom-left-radius: 3px;
}

DIV.batchPages A:last-child {
	border-right-color: transparent;
	border-bottom-right-radius: 3px;
}

DIV.batchPages A.current,
DIV.batchPages A.current:hover {
	color: #666;
	background-color: #ebebeb;
	background-image: -moz-linear-gradient(#fcfcfc, #ebebeb);
	background-image: -webkit-linear-gradient(#fcfcfc, #ebebeb);
	background-image: linear-gradient(#fcfcfc, #ebebeb);
	background-repeat: repeat-x;
	border-top: 1px solid transparent;
	border-right: 1px solid rgba(0,0,0,0.04);
	border-left: 1px solid rgba(255,255,255,0.7);
	border-bottom: 1px solid #444;
}


/**
 * Overlay
 */

#mask {
	opacity: 0.6;
	filter: alpha(opacity = 60);
}

#osx-container {
	cursor: move;
	background-color: #eee;
	color: #000;
	font-family: "Lucida Grande", Arial, sans-serif;
	font-size: .9em;
	width: 100%;
	border-top-left-radius: 5px;
	border-top-right-radius: 5px;
	border-bottom-left-radius: 5px;
	border-bottom-right-radius: 5px;
	-moz-border-radius-topleft: 5px;
	-moz-border-radius-topright: 5px;
	-moz-border-radius-bottomleft: 5px;
	-moz-border-radius-bottomright: 5px;
	-webkit-border-top-left-radius: 5px;
	-webkit-border-top-right-radius: 5px;
	-webkit-border-bottom-left-radius: 5px;
	-webkit-border-bottom-right-radius: 5px;
}

#osx-container SPAN.close {
	cursor: pointer;
	position: absolute;
	right: 15px;
	top: 20px;
	opacity: 0.5;
	filter: alpha(opacity = 50);
}

#osx-container SPAN.close:hover {
	opacity: 1;
	filter: alpha(opacity = 100);
}

#osx-modal-title {
	color: #000;
	background-color: #ddd;
	border-bottom: 1px solid #ccc;
	padding: 6px 8px;
	font-size: 130% !important;
	font-weight: bold;
	text-shadow: 0 1px 0 #f4f4f4;
	border-top-left-radius: 5px;
	border-top-right-radius: 5px;
	-moz-border-radius-topleft: 5px;
	-moz-border-radius-topright: 5px;
	-webkit-border-top-left-radius: 5px;
	-webkit-border-top-right-radius: 5px;
}

DIV.overlay {
	display: none;
	background-color: silver;
	width: auto;
	min-width: 825px;
	border: 2px solid #666;
	border: 2px solid rgba(98, 122, 160, 0.698);
	border-radius: 5px;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	box-shadow: 5px 5px 35px #000;
	-moz-box-shadow: 5px 5px 35px #000;
	-webkit-box-shadow: 5px 5px 35px #000;
}

DIV.overlay DIV.form DIV.viewspace,
DIV.overlay DIV.display-form DIV.viewspace {
	max-height: 450px;
	overflow: auto;
}

DIV.overlay DIV.viewspace DIV.jquery-multiselect-autocomplete {
	position: fixed;
}


/**
 * Internal references widget style
 */
#selector {
	display: none;
	overflow: auto;
	height: 200px;
	background-color: infobackground;
	border-right: 1px solid silver;
	border-bottom: 1px solid silver;
	border-left: 1px solid silver;
}

#selector DIV.reference {
	padding: 2px 10px 2px 20px;
	border-bottom: 1px solid silver;
	cursor: pointer;
}


/**
 * JQuery tools tabs
 */

#tabforms UL.tabs {
	margin: 0 !important;
	padding: 0;
	height: 30px;
	border-bottom: 1px solid #dcdcdc;
}

#tabforms UL.tabs LI {  
	float: left;
	padding: 0;
	margin: 0;
	list-style-type: none;
}

#tabforms UL.tabs A { 
	float: left;
	font-size: 13px;
	display: block;
	padding: 5px 30px;
	text-decoration: none;
	border: 1px solid #dcdcdc;
	border-bottom: 0px;
	height: 18px;
	background-color: #fdfdfd;
	color: #777;
	margin-right: 2px;
	position: relative;
	top: 1px;
	outline: 0;
	border-radius: 4px 4px 0px 0px;
	-moz-border-radius: 4px 4px 0px 0px;
	-webkit-border-radius: 4px 4px 0px 0px;
}

#tabforms UL.tabs A:hover {
	background-color: white;
	color: #444;
}

#tabforms UL.tabs A.current,
#tabforms UL.tabs A.current:hover {
	background-color: #eee;
	border-bottom: 1px solid #eee;
	cursor: default;
}

#tabforms UL.tabs LI.error A {
	color: red !important;
}

#tabforms DIV.panes > DIV {
	border: 1px solid #dcdcdc;
	border-width: 0 1px 1px 1px;
	min-height: 150px;
	padding: 10px;
	background-color: #eee;
}


/**
 * ProgressBar style
 */

IFRAME.progress {
	border: none;
	padding: none;
	margin: none;
	display: block;
	float: right;
	width: 120px;
	height: 50px;
	overflow: hidden;
}

BODY.progressbar {
	margin: 20px 0px 0px;
	padding: 0px;
	background-color: #f9f9f9;
}


/**
 * TinyMCE editor settings
 */

SPAN.mceEditor TABLE.mceLayout {
	width: 99% !important;
}

TD.mceIframeContainer IFRAME {
	min-height: 200px;
}


/**
 * Icons
 */

[class^="icon-"],
[class*=" icon-"] {
	display: inline-block;
	width: 14px;
	height: 14px;
	*margin-right: .3em;
	line-height: 14px;
	vertical-align: text-top;
	background-image: url('/--static--/ztfy.skin/img/glyphicons-halflings.png');
	background-position: 14px 14px;
	background-repeat: no-repeat;
	margin-top: 1px;
}

LEGEND [class^="icon-"],
LEGEND [class*=" icon-"] {
	margin-top: 0px;
}

[class^="icon-"][onclick],
[class*=" icon-"][onclick] {
	cursor: pointer;
}

/* White icons with optional class, or on hover/active states of certain elements */
.icon-white,
.nav-pills > .active > a > [class^="icon-"],
.nav-pills > .active > a > [class*=" icon-"],
.nav-list > .active > a > [class^="icon-"],
.nav-list > .active > a > [class*=" icon-"],
.navbar-inverse .nav > .active > a > [class^="icon-"],
.navbar-inverse .nav > .active > a > [class*=" icon-"],
.dropdown-menu > li > a:hover > [class^="icon-"],
.dropdown-menu > li > a:hover > [class*=" icon-"],
.dropdown-menu > .active > a > [class^="icon-"],
.dropdown-menu > .active > a > [class*=" icon-"],
.dropdown-submenu:hover > a > [class^="icon-"],
.dropdown-submenu:hover > a > [class*=" icon-"] {
	background-image: url('/--static--/ztfy.skin/img/glyphicons-halflings-white.png');
}

.icon-glass {
	background-position: 0 0;
}
.icon-music {
	background-position: -24px 0;
}
.icon-search {
	background-position: -48px 0;
}
.icon-envelope {
	background-position: -72px 0;
}
.icon-heart {
	background-position: -96px 0;
}
.icon-star {
	background-position: -120px 0;
}
.icon-star-empty {
	background-position: -144px 0;
}
.icon-user {
	background-position: -168px 0;
}
.icon-film {
	background-position: -192px 0;
}
.icon-th-large {
	background-position: -216px 0;
}
.icon-th {
	background-position: -240px 0;
}
.icon-th-list {
	background-position: -264px 0;
}
.icon-ok {
	background-position: -288px 0;
}
.icon-remove {
	background-position: -312px 0;
}
.icon-zoom-in {
	background-position: -336px 0;
}
.icon-zoom-out {
	background-position: -360px 0;
}
.icon-off {
	background-position: -384px 0;
}
.icon-signal {
	background-position: -408px 0;
}
.icon-cog {
	background-position: -432px 0;
}
.icon-trash {
	background-position: -456px 0;
}
.icon-home {
	background-position: 0 -24px;
}
.icon-file {
	background-position: -24px -24px;
}
.icon-time {
	background-position: -48px -24px;
}
.icon-road {
	background-position: -72px -24px;
}
.icon-download-alt {
	background-position: -96px -24px;
}
.icon-download {
	background-position: -120px -24px;
}
.icon-upload {
	background-position: -144px -24px;
}
.icon-inbox {
	background-position: -168px -24px;
}
.icon-play-circle {
	background-position: -192px -24px;
}
.icon-repeat {
	background-position: -216px -24px;
}
.icon-refresh {
	background-position: -240px -24px;
}
.icon-list-alt {
	background-position: -264px -24px;
}
.icon-lock {
	background-position: -287px -24px;
}
.icon-flag {
	background-position: -312px -24px;
}
.icon-headphones {
	background-position: -336px -24px;
}
.icon-volume-off {
	background-position: -360px -24px;
}
.icon-volume-down {
	background-position: -384px -24px;
}
.icon-volume-up {
	background-position: -408px -24px;
}
.icon-qrcode {
	background-position: -432px -24px;
}
.icon-barcode {
	background-position: -456px -24px;
}
.icon-tag {
	background-position: 0 -48px;
}
.icon-tags {
	background-position: -25px -48px;
}
.icon-book {
	background-position: -48px -48px;
}
.icon-bookmark {
	background-position: -72px -48px;
}
.icon-print {
	background-position: -96px -48px;
}
.icon-camera {
	background-position: -120px -48px;
}
.icon-font {
	background-position: -144px -48px;
}
.icon-bold {
	background-position: -167px -48px;
}
.icon-italic {
	background-position: -192px -48px;
}
.icon-text-height {
	background-position: -216px -48px;
}
.icon-text-width {
	background-position: -240px -48px;
}
.icon-align-left {
	background-position: -264px -48px;
}
.icon-align-center {
	background-position: -288px -48px;
}
.icon-align-right {
	background-position: -312px -48px;
}
.icon-align-justify {
	background-position: -336px -48px;
}
.icon-list {
	background-position: -360px -48px;
}
.icon-indent-left {
	background-position: -384px -48px;
}
.icon-indent-right {
	background-position: -408px -48px;
}
.icon-facetime-video {
	background-position: -432px -48px;
}
.icon-picture {
	background-position: -456px -48px;
}
.icon-pencil {
	background-position: 0 -72px;
}
.icon-map-marker {
	background-position: -24px -72px;
}
.icon-adjust {
	background-position: -48px -72px;
}
.icon-tint {
	background-position: -72px -72px;
}
.icon-edit {
	background-position: -96px -72px;
}
.icon-share {
	background-position: -120px -72px;
}
.icon-check {
	background-position: -144px -72px;
}
.icon-move {
	background-position: -168px -72px;
}
.icon-step-backward {
	background-position: -192px -72px;
}
.icon-fast-backward {
	background-position: -216px -72px;
}
.icon-backward {
	background-position: -240px -72px;
}
.icon-play {
	background-position: -264px -72px;
}
.icon-pause {
	background-position: -288px -72px;
}
.icon-stop {
	background-position: -312px -72px;
}
.icon-forward {
	background-position: -336px -72px;
}
.icon-fast-forward {
	background-position: -360px -72px;
}
.icon-step-forward {
	background-position: -384px -72px;
}
.icon-eject {
	background-position: -408px -72px;
}
.icon-chevron-left {
	background-position: -432px -72px;
}
.icon-chevron-right {
	background-position: -456px -72px;
}
.icon-plus-sign {
	background-position: 0 -96px;
}
.icon-minus-sign {
	background-position: -24px -96px;
}
.icon-remove-sign {
	background-position: -48px -96px;
}
.icon-ok-sign {
	background-position: -72px -96px;
}
.icon-question-sign {
	background-position: -96px -96px;
}
.icon-info-sign {
	background-position: -120px -96px;
}
.icon-screenshot {
	background-position: -144px -96px;
}
.icon-remove-circle {
	background-position: -168px -96px;
}
.icon-ok-circle {
	background-position: -192px -96px;
}
.icon-ban-circle {
	background-position: -216px -96px;
}
.icon-arrow-left {
	background-position: -240px -96px;
}
.icon-arrow-right {
	background-position: -264px -96px;
}
.icon-arrow-up {
	background-position: -289px -96px;
}
.icon-arrow-down {
	background-position: -312px -96px;
}
.icon-share-alt {
	background-position: -336px -96px;
}
.icon-resize-full {
	background-position: -360px -96px;
}
.icon-resize-small {
	background-position: -384px -96px;
}
.icon-plus {
	background-position: -408px -96px;
}
.icon-minus {
	background-position: -433px -96px;
}
.icon-asterisk {
	background-position: -456px -96px;
}
.icon-exclamation-sign {
	background-position: 0 -120px;
}
.icon-gift {
	background-position: -24px -120px;
}
.icon-leaf {
	background-position: -48px -120px;
}
.icon-fire {
	background-position: -72px -120px;
}
.icon-eye-open {
	background-position: -96px -120px;
}
.icon-eye-close {
	background-position: -120px -120px;
}
.icon-warning-sign {
	background-position: -144px -120px;
}
.icon-plane {
	background-position: -168px -120px;
}
.icon-calendar {
	background-position: -192px -120px;
}
.icon-random {
	background-position: -216px -120px;
	width: 16px;
}
.icon-comment {
	background-position: -240px -120px;
}
.icon-magnet {
	background-position: -264px -120px;
}
.icon-chevron-up {
	background-position: -288px -120px;
}
.icon-chevron-down {
	background-position: -313px -119px;
}
.icon-retweet {
	background-position: -336px -120px;
}
.icon-shopping-cart {
	background-position: -360px -120px;
}
.icon-folder-close {
	background-position: -384px -120px;
}
.icon-folder-open {
	background-position: -408px -120px;
	width: 16px;
}
.icon-resize-vertical {
	background-position: -432px -119px;
}
.icon-resize-horizontal {
	background-position: -456px -118px;
}
.icon-hdd {
	background-position: 0 -144px;
}
.icon-bullhorn {
	background-position: -24px -144px;
}
.icon-bell {
	background-position: -48px -144px;
}
.icon-certificate {
	background-position: -72px -144px;
}
.icon-thumbs-up {
	background-position: -96px -144px;
}
.icon-thumbs-down {
	background-position: -120px -144px;
}
.icon-hand-right {
	background-position: -144px -144px;
}
.icon-hand-left {
	background-position: -168px -144px;
}
.icon-hand-up {
	background-position: -192px -144px;
}
.icon-hand-down {
	background-position: -216px -144px;
}
.icon-circle-arrow-right {
	background-position: -240px -144px;
}
.icon-circle-arrow-left {
	background-position: -264px -144px;
}
.icon-circle-arrow-up {
	background-position: -288px -144px;
}
.icon-circle-arrow-down {
	background-position: -312px -144px;
}
.icon-globe {
	background-position: -336px -144px;
}
.icon-wrench {
	background-position: -360px -144px;
}
.icon-tasks {
	background-position: -384px -144px;
}
.icon-filter {
	background-position: -408px -144px;
}
.icon-briefcase {
	background-position: -432px -144px;
}
.icon-fullscreen {
	background-position: -456px -144px;
}
